findpeaks
----------

.. currentmodule:: eqcorrscan.utils.findpeaks
.. automodule:: eqcorrscan.utils.findpeaks

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       coin_trig
       decluster
       find_peaks_compiled
       find_peaks2_short
       multi_find_peaks

    .. comment to end block
